Skip to main content

totra

an unofficial TopTracker CLI helper

Purpose

TopTracker is great time tracking tool, but when it comes to making polls, reports etc. I find CLI tools much more productive then clicking around web page.

The idea went from simple question: how much hours I've worked i.e this week ?

With TopTracker web page, to know such information I had to: login to web page, click on date range, export activities to csv, open spreadsheet software and import this csv, and then sum. With this tool I can just:

totra how_much_hours --workers="Andrzej Bargański" --from=Monday -l my@login.com -p mypassword

...and in second you see result !

Usage

Notice: Application is still in planning stage. Commands, options etc. can change, and every TopTracker user is invited to post thoughts, wishes and participate in development.

   totra activities [--format=<format>] [--projects=<projects>] [--workers=<workers>] --from=<from_date> [--to=<to_date>] [-l login] [-p password] [-o output_filename]
   totra how_much_hours [--projects=<projects>] [--workers=<workers>] --from=<from_date> [--to=<to_date>] [-l login] [-p password]
   totra -h | --help
   totra --version

 Commands:
   activities                Output activities in --format.
   how_much_hours            Shows how much work hours are registered according to given parameters.

 Options:
   --format=<format>         Output format. Can be: json, excel. [default: json]
   --projects=<projects>     Projects names as coma separated list. Ex. 'Project 1' or 'Project 1,Project 2'
   --workers=<workers>       Workers as coma seprated list. Ex. 'Worker Name' or 'Worker Name 1, Worker Name 2'
   --from=<from_date>        Date as beginning of period for data retrieval. Format is: YYYY-mm-dd , ex: 2018-05-01
   --to=<to_date>            Date as end of period for data retrieval. Format is: YYYY-mm-dd , ex: 2018-05-01. [default: now].
   -o output_filename        Output filename to write data. Default is stdout (print on your screen) [default: stdout]
   -h --help                 Show this screen.
   --version                 Show version.
   -l login                  User login name.
   -p password               User password.

Installation

First if you missing Python 3.6 on your system, download it from here. Next execute on command line : pip install totra

Metadata

Release files for totra 0.1.3

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for totra 0.1.3
File Size Uploaded Provenance Actions
totra-0.1.3.tar.gz 10.9 kB Without provenance Details for totra-0.1.3.tar.gz

Built distribution (wheel)

Table of built distributions (wheels) for totra 0.1.3
File Interpreter ABI Platform Actions
totra-0.1.3-py3-none-any.whl Python 3 none any Details for totra-0.1.3-py3-none-any.whl

Total release size: 19.8 kB

Release files / totra-0.1.3.tar.gz

Download URL totra-0.1.3.tar.gz
Size 10.9 kB
Tags Source
SHA-256 checksum
How to use checksums
3208cddd63da702b0b924c8b309e9ca1877d5404b7d2e671d456831f4b47e582
BLAKE2b-256 checksum
How to use checksums
defa87805a5d760c4779e05b841388c2f3650d49c9941a7ef4d200029c3aea99
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No

Release files / totra-0.1.3-py3-none-any.whl

Download URL totra-0.1.3-py3-none-any.whl
Size 9.0 kB
Tags Python 3
SHA-256 checksum
How to use checksums
279e02d66c42ab850021b54f0c3663fa91465d37e3b9bb6f73e7eda090cb75cf
BLAKE2b-256 checksum
How to use checksums
151961e4375b4aac03219fcbb304dcffe47f6d1eec1838b7219c657394c2dff5
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No

Security for totra 0.1.3

Provenance

Provenance describes where a file came from. On PyPI, provenance is shared via attestations, which provide a verifiable record of the build or publishing details. View details, limitations and caveats.

No provenance found

None of the files in this release were uploaded with provenance metadata.

A note on package security

PyPI is a repository for distributing packages, not a service for auditing them. While third-party security researchers and our staff do their best to detect and remove malicious packages, PyPI cannot guarantee the quality, security or suitability of any given package.

To learn more about protecting yourself from malicious actors, visit our package security documentation.

Release history Release notifications | RSS feed

This release

0.1.3 This release

2 release files No provenance

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page